@@ -1,8 +1,6 @@
 /*
  * config.c	Read and write the configuration file(s).
  *
- * 		$Id: config.c,v 1.2 1999/09/03 12:25:24 walker Exp $
- *
  *		This file is part of the minicom communications package,
  *		Copyright 1991-1995 Miquel van Smoorenburg.
  *
@@ -26,8 +24,15 @@
  *    jl 29.11.98 - the P_SHOWSPD option
  *    jl 05.04.99 - logging options menu
  *    er 18-Apr-99 - the P_MULTILINE option
- *    jl 07.01.2000 - the P_STOPB option
+ *    jl 11.02.2000 - the P_STOPB option
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: config.c,v 1.7 2000/10/28 12:51:43 walker Exp $")
+
 #include "port.h"
 #include "minicom.h"
 #include "intl.h"
@@ -335,9 +340,11 @@ static void dopath()
   		return;
   	case 'A':
   		pgets(w, strlen (download_directory) + 1, 0, P_DOWNDIR, 64, 64);
+		init_dir('d');
   		break;
   	case 'B':
   		pgets(w, strlen (upload_directory) + 1, 1, P_UPDIR, 64, 64);
+		init_dir('u');
   		break;
   	case 'C':
   		pgets(w, strlen (script_directory) + 1, 2, P_SCRIPTDIR, 64, 64);
@@ -805,7 +812,6 @@ static void doscrkeyb()
       * background_color_stat = _(" J - Background Color (stat):"),
       * history_buffer_size = _(" K - History Buffer Size    :"),
       * question = _("Change which setting?  (Esc to exit)");
-
 #if _HAVE_MACROS
   char* macros_file = _(" L - Macros file            :"),
       * macros_enabled = _(" N - Macros enabled         :"),
@@ -1348,7 +1354,7 @@ int setup;
 
 /* fmg 1/11/94 Color names for menu */
 
-static char *J_col[] =
+char *J_col[] =
   { N_("BLACK"), N_("RED"), N_("GREEN"), N_("YELLOW"),
     N_("BLUE"), N_("MAGENTA"), N_("CYAN"), N_("WHITE") };
 
@@ -1386,11 +1392,11 @@ int curr_ok;
   if (max > 96)
 	wputs(w, _(" F: 19200                      Stopbits\n"));
   else
-	wputs(w, _("                               Stopbits\n"));
+	wputs(w, "                               Stopbits\n");
   if (max > 192)
-  	wputs(w, _(" G: 38400                         W: 1\n"));
+	wputs(w, _(" G: 38400                         W: 1\n"));
   else
-	wputs(w, "                                    W: 1\n");
+	wputs(w, _("                                    W: 1\n"));
   if (max > 384)
 	wputs(w, _(" H: 57600                         X: 2\n"));
   else
@@ -1418,7 +1424,7 @@ int curr_ok;
 
   while(1) {
   	wlocate(w, 1, 1);
-  	wprintf(w, _("Current: %5s %s%s%c  "), ba, bi, pa, stopb[0]);
+  	wprintf(w, _("Current: %5s %s%s%s  "), ba, bi, pa, stopb);
   	wlocate(w, x, y);
   	wflush();
   	c = wxgetch();
@@ -1480,11 +1486,11 @@ int curr_ok;
   		case 'V':
   			bi[0] = '8';
   			break;
-		case 'W':
-			stopb[0] = '1';
+  		case 'W':
+  			stopb[0] = '1';
 			break;
-		case 'X':
-			stopb[0] = '2';
+  		case 'X':
+  			stopb[0] = '2';
 			break;
   		case 27:
   		case '\n':
@@ -1689,25 +1695,25 @@ void doconv()
       strcpy(buf,P_CONVF);
       prompt=_("Load file: %s");
       wprintf(w, prompt, buf);
-      pgets(w, strlen(prompt) - 1, ymax - 1, buf, 64, 64);
-      if (loadconv(buf) == 0) {
+      pgets(w, strlen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+      if (loadconv(P_CONVF) == 0) {
 	if(strcmp(P_CONVF,buf))
 	  markch(P_CONVF);
-	strcpy(P_CONVF,buf);
 	redraw=1;
-      }
+      } else
+	strcpy(P_CONVF,buf);
       break;
     case 'B':
       strcpy(buf,P_CONVF);
       prompt=_("Save as file: %s");
       wprintf(w, prompt, buf);
-      pgets(w, strlen(prompt) - 1, ymax - 1, buf, 64, 64);
-      if (saveconv(buf) == 0) {
+      pgets(w, strlen(prompt) - 1, ymax - 1, P_CONVF, 64, 64);
+      if (saveconv(P_CONVF) == 0) {
 	if(strcmp(P_CONVF,buf))
 	  markch(P_CONVF);
-	strcpy(P_CONVF,buf);
 	redraw=1;
-      }
+      } else
+	strcpy(P_CONVF,buf);
       break;
     case 'C':
       prompt=_("Character to be edited: ");
