@@ -19,13 +19,21 @@
  *				command line
  * jl  09.07.98 added option -S to start a script at startup
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID(PKG_VER "$Id: minicom.c,v 1.14 2001/07/04 14:43:25 kloczek Exp $")
+
+#include <getopt.h>
 
 #define EXTERN
 #include "port.h"
 #include "minicom.h"
-#include "patchlevel.h"
 #include "intl.h"
 
+
 #define RESET 1
 #define NORESET 2
 
@@ -816,17 +824,13 @@ char **s;
   return(begin);
 }
 
-static char *bletch = 
-  N_("Usage: minicom [-somlz8] [-c on] [-a on] [-t TERM] [-S scriptname] [-d entry]\n\t[-p ttyp] [-C capturefile] [configuration]\n");
-
 static void usage(env_args, optind, mc)
 int env_args, optind;
 char *mc;
 {
   if (env_args >= optind && mc)
-  	fprintf(stderr, _("Wrong option in environment MINICOM=%s\n"), mc);
-  fputs(_(bletch), stderr);
-  fputs(_("Type \"minicom -h\" for help.\n"), stderr);
+	 fprintf(stderr, _("Wrong option in environment MINICOM=\"%s\"\n"), mc);
+  fprintf(stderr, _("Type \"minicom %s\" for help.\n"), "--help");
   exit(1);
 }
 
@@ -835,39 +839,32 @@ static void helpthem()
 {
   char *mc = getenv("MINICOM");
 
-  printf("\n%s", Version);
-#ifdef __DATE__
-  printf(_(" (compiled %s)"), __DATE__);
-#endif /*__DATE_*/
-  printf(_("(c) Miquel van Smoorenburg\n\n%s\n"), _(bletch));
-  fputs(_("  -s             : enter setup mode (only as root)\n"),stdout);
-  fputs(_("  -o             : do not initialize modem & lockfiles at startup\n"), stdout);
-  fputs(_("  -m             : use meta or alt key for commands\n"), stdout);
-  fputs(_("  -l             : literal ; assume screen uses the IBM-PC character set\n"), stdout);
-  fputs(_("  -L             : Ditto, but assume screen uses ISO8859\n"), stdout); 
-  fputs(_("  -z             : try to use terminal's status line\n"), stdout);
-  fputs(_("  -8             : 8bit clean mode (for Japanese, etc)\n"), stdout);
-  fputs(_("  -c [on | off]  : ANSI style color usage on or off\n"), stdout);
-  fputs(_("  -a [on | off]  : use reverse or highlight attributes on or off\n"), stdout);
-  fputs(_("  -t term        : override TERM environment variable\n"), stdout);
-  fputs(_("  -S scriptname  : run script at startup\n"), stdout);
-  fputs(_("  -d entry       : dial `entry' from the dialing directory\n"), stdout);
-  fputs(_("  -p ttyp..      : connect to pseudo terminal\n"), stdout);
-  fputs(_("  -C filename    : start capturing with the file name\n"), stdout);
-  fputs(_("  configuration  : configuration file to use\n\n"), stdout);
-  fputs(_("These options can also be specified in the MINICOM environment variable.\n"), stdout);
-  printf(_("This variable is currently %s%s.\n"), mc ? _("set to ") : _("unset"),
+  printf(_("Usage: %s [OPTION]... [configuration]\n"), PACKAGE);
+  printf(_("A terminal program for Linux and other unix-like systems.\n\n"));
+  printf(_("  -s, --setup            : enter setup mode (only as root)\n"));
+  printf(_("  -o, --noinit           : do not initialize modem & lockfiles at startup\n"));
+  printf(_("  -m, --metakey          : use meta or alt key for commands\n"));
+  printf(_("  -M, --metakey8         : use 8bit meta key for commands\n"));
+  printf(_("  -l, --ansi             : literal; assume screen uses the IBM-PC character set\n"));
+  printf(_("  -L, --iso              : Ditto, but assume screen uses ISO8859\n")); 
+  printf(_("  -w, --wrap             : Linewrap on\n"));
+  printf(_("  -z, --statline         : try to use terminal's status line\n"));
+  printf(_("  -8, --8bit             : 8bit clean mode (for Japanese, etc)\n"));
+  printf(_("  -c, --color=on/off     : ANSI style color usage on or off\n"));
+  printf(_("  -a, --attrib=on/off    : use reverse or highlight attributes on or off\n"));
+  printf(_("  -t, --term=TERM        : override TERM environment variable\n"));
+  printf(_("  -S, --script=SCRIPT    : run SCRIPT at startup\n"));
+  printf(_("  -d, --dial=ENTRY       : dial ENTRY from the dialing directory\n"));
+  printf(_("  -p, --ptty=TTYP        : connect to pseudo terminal\n"));
+  printf(_("  -C, --capturefile=FILE : start capturing to FILE\n"));
+  printf(_("  -v, --version          : output version information and exit\n"));
+  printf(_("  configuration          : configuration file to use\n\n"));
+  printf(_("These options can also be specified in the MINICOM environment variable.\n"));
+  printf(_("This variable is currently %s\"%s\".\n"), mc ? _("set to ") : _("unset"),
 	mc ? mc : "");
-  fputs(_("The LIBDIR to find the configuration files and the\n"), stdout);
-  printf(_("access file minicom.users is compiled as %s.\n\n"), LIBDIR);
-
-#if 0  /* More than 24 lines.. */
-  printf("\
-This program is free software; you can redistribute it and/or\n\
-modify it under the terms of the GNU General Public License\n\
-as published by the Free Software Foundation; either version\n\
-2 of the License, or (at your option) any later version.\n\n");
-#endif
+  printf(_("The LIBDIR to find the configuration files and the access file\n"));
+  printf(_("minicom.users is compiled as %s.\n\n"), LIBDIR);
+  printf(_("Report bugs to <minicom-devel@bazar.conectiva.com.br>.\n"));
 
 }
 
@@ -898,10 +895,33 @@ char **argv;
   char pseudo[64];
 /*  char* console_encoding = getenv ("LC_CTYPE"); */
 
-#ifdef _I18N_
-  bindtextdomain("minicom", "/usr/share/locale");
-  textdomain("minicom");
-#endif
+  static struct option long_options[] =
+  {
+	  { "setup", no_argument, NULL, 's' },
+	  { "help", no_argument, NULL, 'h' },
+	  { "ptty", required_argument, NULL, 'p' },
+	  { "metakey", no_argument, NULL, 'm' },
+	  { "metakey8", no_argument, NULL, 'M' },
+	  { "ansi", no_argument, NULL, 'l' },
+	  { "iso", no_argument, NULL, 'L' },
+	  { "term", required_argument, NULL, 't' },
+	  { "noinit", no_argument, NULL, 'o' },
+	  { "color", required_argument, NULL, 'c' },
+	  { "attrib", required_argument, NULL, 'a' },
+	  { "dial", required_argument, NULL, 'd' },
+	  { "statline", no_argument, NULL, 'z' },
+	  { "capturefile", required_argument, NULL, 'C' },
+	  { "script", required_argument, NULL, 'S' },
+	  { "8bit", no_argument, NULL, '8' },
+	  { "version", no_argument, NULL, 'v' },
+	  { "wrap", no_argument, NULL, 'w' },
+	  { NULL, 0, NULL, 0 }
+  };
+
+  /* initialize locale support */
+  setlocale(LC_ALL, "");
+  bindtextdomain(PACKAGE, LOCALEDIR);
+  textdomain(PACKAGE);
 
   /* Initialize global variables */
   portfd = -1;
@@ -912,7 +932,8 @@ char **argv;
   stdattr = XA_NORMAL;
   us = NIL_WIN;
   addlf = 0;
-#ifdef _SELECT
+  wrapln = 0;
+#ifdef HAVE_SELECT
   local_echo = 0;
 #endif /*SELECT*/
   strcpy(capname, "minicom.cap");
@@ -996,11 +1017,25 @@ char **argv;
 
   do {
 	/* Process options with getopt */
-	while((c = getopt(argk, args, "8zhlLsomMbc:a:t:d:p:C:S:")) != EOF)
+	while((c = getopt_long(argk, args, "v8zhlLsomMbwc:a:t:d:p:C:S:",
+					long_options, NULL)) != EOF)
 	  switch(c) {
+		case 'v':
+			printf(_("%s version %s"), PACKAGE, VERSION);
+#ifdef __DATE__
+			printf(_(" (compiled %s)"), __DATE__);
+#endif
+			printf("\n");
+			printf(_("Copyright (C) Miquel van Smoorenburg.\n\n"));
+			printf("This program is free software; you can redistribute it and/or\n"
+			       "modify it under the terms of the GNU General Public License\n"
+			       "as published by the Free Software Foundation; either version\n"
+			       "2 of the License, or (at your option) any later version.\n\n");
+			exit(1);
+			break;
   		case 's': /* setup */
   			if (real_uid != 0 && real_uid != eff_uid) {
-		fputs(_("minicom: -s switch needs root privilige\n"), stderr);
+				fprintf(stderr, _("minicom: -s switch needs root privilige\n"));
 				exit(1);
 			}
   			dosetup = 1;
@@ -1012,10 +1047,13 @@ char **argv;
 		case 'p': /* Pseudo terminal to use. */
 			if (strncmp(optarg, "/dev/", 5) == 0)
 				optarg += 5;
-			if (strncmp(optarg, "tty", 3) != 0 ||
-			    !strchr("pqrstuvwxyz", optarg[3])) {
-				fputs(
-				 _("minicom: argument to -p must be a pty\n"), stderr);
+			if (((strncmp(optarg, "tty", 3) != 0)
+					/* /dev/pts support --misiek. */
+					&& (strncmp(optarg, "pts", 3) != 0)
+					/* /dev/pty support --jl. */
+					&& (strncmp(optarg, "pty", 3) != 0))
+					|| !strchr("pqrstuvwxyz/", optarg[3])) {
+				fprintf(stderr, _("minicom: argument to -p must be a pty\n"));
 				exit(1);
 			}
 			snprintf(pseudo, sizeof(pseudo), "/dev/%s", optarg);
@@ -1095,7 +1133,10 @@ char **argv;
 			vt_set(-1, -1, (FILE*)NULL, -1, -1, -1, -1, 1);
 			screen_ibmpc++; screen_iso++;
 			break;
-  		default:
+		case 'w': /* Linewrap on */
+			wrapln = 1;
+			break;
+		default:
   			usage(env_args, optind, mc);
   			break;
   	}
@@ -1107,13 +1148,15 @@ char **argv;
     /* Loop again if more options */
   } while(optind < argk);
 
+#ifdef SVR4_LOCKS
   if (real_uid == 0 && dosetup == 0) {
-    fprintf(stderr, "%s%s%s",
-_("minicom: WARNING: please don't run minicom as root when not maintaining\n"),
-_("                  it (with the -s switch) since all changes to the\n"),
-_("                  configuration will be GLOBAL !.\n"));
-    sleep(5);
+    fprintf(stderr, "%s",
+_("minicom: WARNING: please don't run minicom as root when not maintaining\n"
+  "                  it (with the -s switch) since all changes to the\n"
+  "                  configuration will be GLOBAL !.\n"));
+ 	sleep(5);
   }
+#endif
 
   /* Avoid fraude ! */	
   for(s = use_port; *s; s++) if (*s == '/') *s = '_';
@@ -1214,6 +1257,7 @@ _("                  configuration will be GLOBAL !.\n"));
 	  exit(1);
   }
 
+  /* Signal handling */
   signal(SIGTERM, hangsig);
   signal(SIGHUP, hangsig);
   signal(SIGINT, SIG_IGN);
@@ -1267,7 +1311,7 @@ _("                  configuration will be GLOBAL !.\n"));
  
   if (doinit) modeminit();
  
-  wprintf(us, "\n%s\r\n", _(CR_VERSION));
+  wprintf(us, "\n%s %s\r\n", _("Welcome to minicom"), VERSION);
   wprintf(us, "\n%s: %s%s%s%s%s\r\n", _("OPTIONS"),
 	  CR_OPTION1,CR_OPTION2,CR_OPTION3,CR_OPTION4,CR_OPTION5);
 #if defined (__DATE__) && defined (__TIME__)
@@ -1294,15 +1338,15 @@ dirty_goto:
 			vt_set(addlf, -1, NULL, -1, -1, -1, -1, -1);
 			s = addlf ?
 			  _("Add linefeed ON") : _("Add linefeed OFF");
-			werror(s);
+			werror("%s", s);
 			break;
-#if _SELECT
+#ifdef HAVE_SELECT
 		case 'e': /* Local echo on/off. */
 			local_echo = !local_echo;
 			vt_set(-1, -1, NULL, -1, -1, local_echo, -1 ,-1);
 			s = local_echo ?
 			  _("Local echo ON") : _("Local echo OFF");
-			werror(s);
+			werror("%s", s);
 			break;
 #endif
 		case 'z': /* Help */
@@ -1417,7 +1461,7 @@ dirty_goto:
 			c = (!us->wrap);
 			vt_set(addlf, c, capfp, docap, -1, -1, -1, -1);
 			s = c ? _("Linewrap ON") : _("Linewrap OFF");
-			werror(s);
+			werror("%s", s);
 			break;
 		case 'o': /* Configure Minicom */
 			(void) config(0);
@@ -1449,7 +1493,7 @@ dirty_goto:
 	m_restorestate(portfd);
   else {
         if (P_LOGCONN[0] == 'Y' && online > 0)
-	  do_log(_("Quit without reset while online."));
+	  do_log("%s", _("Quit without reset while online."));
 	m_hupcl(portfd, 0);
   }
   if (capfp != (FILE *)0) fclose(capfp);
