@@ -18,12 +18,18 @@
  * // jl 04.09.97 character map conversions in and out
  *    jl 06.07.98 use conversion tables with the capture file
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: vt100.c,v 1.3 2000/02/09 08:34:57 misiek Exp $")
+
 #include "port.h"
 #include "window.h"
 #include "vt100.h"
 #include "config.h"
 #include "configsym.h"
-#include "patchlevel.h"
 
 #define OLD 0
 
@@ -154,7 +160,7 @@ static char *vt_trans[2];
 static int vt_charset = 0;	/* Character set. */
 #endif
 
-#ifdef _SELECT
+#ifdef HAVE_SELECT
 static int vt_echo;		/* Local echo on/off. */
 #endif
 int vt_nl_delay;		/* Delay after CR key */
@@ -250,7 +256,7 @@ int add;
   wresetregion(vt_win);
   vt_keypad = NORMAL;
   vt_cursor = NORMAL;
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   vt_echo = 0;
 #endif
   vt_tabs[0] = 0x01010100;
@@ -292,7 +298,7 @@ int asis;
   if (capfp != (FILE *)0) vt_capfp = capfp;
   if (docap >= 0) vt_docap = docap;
   if (bscode >= 0) vt_bs = bscode;
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   if (echo >= 0) vt_echo = echo;
 #endif
   if (cursor >= 0) vt_cursor = cursor;
@@ -304,7 +310,7 @@ static void v_termout(s, len)
 char *s;
 int len;
 {
-#ifdef _SELECT
+#ifdef HAVE_SELECT
   char *p;
 
   if (vt_echo) {
@@ -948,7 +954,7 @@ int ch;
 			go_on = 1;
 			break;
 		}
-		v_termout(SCCS_ID, 0);
+		v_termout("Minicom" VERSION, 0);
 		break;
 	case '\r': /* Carriage return */
 		wputc(vt_win, c);
