@@ -14,6 +14,12 @@
  * 01.01.98 dickey@clark.net: fix for a history window closing bug
  * fmg 8/20/97: Added support for Search of History Buffer
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "rcsid.h"
+RCSID("$Id: window.c,v 1.3 2000/01/27 11:25:31 misiek Exp $")
 
 #include "port.h"
 #include "window.h"
@@ -1852,10 +1858,10 @@ int attr;
 #endif
   switch((f = tgetent(cbuf, term))) {
   	case 0:
-  		fprintf(stderr, "No termcap entry for %s\n", term);
+  		fprintf(stderr, _("No termcap entry for %s\n"), term);
   		return(-1);
   	case -1:
-  		fprintf(stderr, "No termcap database present!\n");
+  		fprintf(stderr, _("No termcap database present!\n"));
   		return(-1);
   	default:
   		break;
@@ -1863,7 +1869,7 @@ int attr;
   _tptr = tbuf;
 
   if ((CM = tgetstr("cm", &_tptr)) == CNULL) {
-  	fprintf(stderr, "No cursor motion capability (cm)\n");
+  	fprintf(stderr, _("No cursor motion capability (cm)\n"));
   	return(-1);
   }
   LINES = COLS = 0;
@@ -1872,11 +1878,11 @@ int attr;
   LINES = lines;
 #endif
   if (LINES == 0 && (LINES = tgetnum("li")) <= 0) {
-  	fprintf(stderr, "Number of terminal lines unknown\n");
+  	fprintf(stderr, _("Number of terminal lines unknown\n"));
   	return(-1);
   }
   if (COLS == 0 && (COLS = tgetnum("co")) <= 0) {
-  	fprintf(stderr, "Number of terminal columns unknown\n");
+  	fprintf(stderr, _("Number of terminal columns unknown\n"));
   	return(-1);
   }
 
